@@ -4,7 +4,7 @@ SPDX-FileCopyrightText: 2013 by Thomas Friedrichsmeier <thomas.friedrichsmeier@k
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
- 
+
 #ifndef RKERRORDIALOG_H
 #define RKERRORDIALOG_H
 
@@ -14,9 +14,9 @@ class QWidget;
 
 namespace RKErrorDialog {
 /** Displays an error message with a button "Report bug" */
-	void reportableErrorMessage (QWidget *parent_widget, const QString &user_message, const QString &details, const QString &caption, const QString &message_code);
+void reportableErrorMessage(QWidget *parent_widget, const QString &user_message, const QString &details, const QString &caption, const QString &message_code);
 /** Open "Report bug" dialog */
-	void reportBug (QWidget *parent_widget = nullptr, const QString &message_info=QString ());
-};
+void reportBug(QWidget *parent_widget = nullptr, const QString &message_info = QString());
+}; // namespace RKErrorDialog
 
 #endif
