@@ -13,19 +13,19 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KLocalizedString>
 #include <KMessageWidget>
 
-#include "../plugin/rkcomponentmap.h"
-#include "../plugin/rkcomponentcontext.h"
 #include "../misc/rkcommonfunctions.h"
-#include "../misc/rkspecialactions.h"
 #include "../misc/rkradiogroup.h"
+#include "../misc/rkspecialactions.h"
+#include "../plugin/rkcomponentcontext.h"
+#include "../plugin/rkcomponentmap.h"
 
 #include "../debug.h"
 
 RKImportDialog::RKImportDialog(const QString &context_id, QWidget *parent) : KAssistantDialog(parent) {
-	RK_TRACE (DIALOGS);
+	RK_TRACE(DIALOGS);
 
 	setWindowTitle(i18n("Import Data Assistant"));
-	rio_handle = RKComponentMap::getComponentHandle("rkward::import_generic_rio");
+	rio_handle = RKComponentMap::getComponentHandle(QStringLiteral("rkward::import_generic_rio"));
 	context = RKComponentMap::getContext(context_id);
 	if (context) {
 		component_ids = context->components();
@@ -34,17 +34,17 @@ RKImportDialog::RKImportDialog(const QString &context_id, QWidget *parent) : KAs
 	for (auto it = component_ids.constBegin(); it != component_ids.constEnd(); ++it) {
 		RKComponentHandle *handle = RKComponentMap::getComponentHandle(*it);
 		if (!handle) {
-			RK_ASSERT (false);
+			RK_ASSERT(false);
 			continue;
 		}
 
-		QString filter = handle->getAttributeValue("format");
-		QString label = handle->getAttributeLabel("format");
+		QString filter = handle->getAttributeValue(QStringLiteral("format"));
+		QString label = handle->getAttributeLabel(QStringLiteral("format"));
 
 		QString elabel = label;
-		elabel.replace ('(', "[");
-		elabel.replace (')', "]");
-		filters.append (elabel + " [" + filter + "] (" + filter + ')');
+		elabel.replace(u'(', u"["_s);
+		elabel.replace(u')', u"]"_s);
+		filters.append(elabel + u" ["_s + filter + u"] ("_s + filter + u')');
 	}
 
 	QWidget *page = new QWidget();
@@ -129,8 +129,8 @@ void RKImportDialog::updateState() {
 	setAppropriate(end_without_selection, !isAppropriate(end_with_selection));
 }
 
-void RKImportDialog::accept () {
-	RK_TRACE (DIALOGS);
+void RKImportDialog::accept() {
+	RK_TRACE(DIALOGS);
 
 	hide();
 	int index = select_format_group->checkedId();
