@@ -7,42 +7,45 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "rkprogresscontrol.h"
 
-#include <QHBoxLayout>
 #include <QCloseEvent>
-#include <QVBoxLayout>
-#include <QScrollBar>
-#include <QTimer>
 #include <QDialog>
 #include <QDialogButtonBox>
+#include <QHBoxLayout>
+#include <QScrollBar>
+#include <QTimer>
+#include <QVBoxLayout>
 
-#include <KLocalizedString>
 #include <KColorScheme>
+#include <KLocalizedString>
 
-#include "../rbackend/rkrinterface.h"
-#include "../settings/rksettingsmoduler.h"
 #include "../misc/rkcommonfunctions.h"
 #include "../misc/rkstyle.h"
+#include "../rbackend/rkrinterface.h"
+#include "../settings/rksettingsmoduler.h"
 
 #include "../debug.h"
 
 /** This class provides the dialog shown as part of an RKProgressControl. Generally you should not use this class directly, but rather use RKProgressControl. */
 class RKProgressControlDialog : public QDialog {
-public:
-/** constructor. */
-	RKProgressControlDialog (const QString &text, const QString &caption, int mode_flags, bool modal);
-/** destructor. */
-	~RKProgressControlDialog ();
-public:
-	void addOutput (const ROutput *output);
-	void finished ();
+  public:
+	/** constructor. */
+	RKProgressControlDialog(const QString &text, const QString &caption, int mode_flags, bool modal);
+	/** destructor. */
+	~RKProgressControlDialog();
+
+  public:
+	void addOutput(const ROutput &output);
+	void finished();
 	void indicateError();
-protected:
-	void closeEvent (QCloseEvent *e) override;
-	void scrollDown ();
-	void toggleDetails ();
-private:
-/** Replace "Cancel" button text with "Close" (to be called, when underlying command has finished */
-	void setCloseTextToClose ();
+
+  protected:
+	void closeEvent(QCloseEvent *e) override;
+	void scrollDown();
+	void toggleDetails();
+
+  private:
+	/** Replace "Cancel" button text with "Close" (to be called, when underlying command has finished */
+	void setCloseTextToClose();
 
 	QLabel *error_indicator;
 	QTextEdit *output_text;
@@ -56,9 +59,8 @@ private:
 	bool is_done;
 };
 
-
-RKProgressControl::RKProgressControl (QObject *parent, const QString &text, const QString &caption, int mode_flags) : QObject (parent) {
-	RK_TRACE (MISC);
+RKProgressControl::RKProgressControl(QObject *parent, const QString &text, const QString &caption, int mode_flags) : QObject(parent) {
+	RK_TRACE(MISC);
 
 	RKProgressControl::text = text;
 	RKProgressControl::caption = caption;
@@ -70,55 +72,55 @@ RKProgressControl::RKProgressControl (QObject *parent, const QString &text, cons
 	autodelete = false;
 }
 
-RKProgressControl::~RKProgressControl () {
-	RK_TRACE (MISC);
+RKProgressControl::~RKProgressControl() {
+	RK_TRACE(MISC);
 
-	if (!is_done) done ();
+	if (!is_done) done();
 }
 
-void RKProgressControl::autoDeleteWhenDone(){
-	RK_TRACE (MISC);
+void RKProgressControl::autoDeleteWhenDone() {
+	RK_TRACE(MISC);
 	autodelete = true;
 	if (outstanding_commands.isEmpty()) deleteLater();
 }
 
-bool RKProgressControl::doModal (bool autodelete) {
-	RK_TRACE (MISC);
-	RK_ASSERT (!dialog);
+bool RKProgressControl::doModal(bool autodelete) {
+	RK_TRACE(MISC);
+	RK_ASSERT(!dialog);
 
 	modal = true;
-	createDialog ();
+	createDialog();
 
-	int res = dialog->exec ();
-	RK_ASSERT ((res == QDialog::Accepted) || (res == QDialog::Rejected));
+	int res = dialog->exec();
+	RK_ASSERT((res == QDialog::Accepted) || (res == QDialog::Rejected));
 
-	bool ret = is_done;		// for good style, we copy this onto the stack, as we are about to self destruct
-	if (autodelete) deleteLater ();
+	bool ret = is_done; // for good style, we copy this onto the stack, as we are about to self destruct
+	if (autodelete) deleteLater();
 
 	return ret;
 }
 
-void RKProgressControl::doNonModal (bool autodelete) {
-	RK_TRACE (MISC);
-	RK_ASSERT (!dialog);
+void RKProgressControl::doNonModal(bool autodelete) {
+	RK_TRACE(MISC);
+	RK_ASSERT(!dialog);
 
 	RKProgressControl::autodelete = autodelete;
-	if ((!dialog) && (mode & ShowAtOnce)) {		// actually, dialog should always be 0 at this point
-		createDialog ();
-		dialog->show ();
+	if ((!dialog) && (mode & ShowAtOnce)) { // actually, dialog should always be 0 at this point
+		createDialog();
+		dialog->show();
 	}
 }
 
-void RKProgressControl::addRCommand (RCommand *command, bool done_when_finished) {
-	RK_TRACE (MISC);
-	RK_ASSERT (command);
+void RKProgressControl::addRCommand(RCommand *command, bool done_when_finished) {
+	RK_TRACE(MISC);
+	RK_ASSERT(command);
 
 	outstanding_commands.append(command);
 	connect(command->notifier(), &RCommandNotifier::commandOutput, this, &RKProgressControl::newOutput);
-	command->whenFinished(this, [this, done_when_finished](RCommand* command) {
-qDebug("finished");
+	command->whenFinished(this, [this, done_when_finished](RCommand *command) {
+		qDebug("finished");
 		if (command->failed()) {
-qDebug("failed");
+			qDebug("failed");
 			if (!dialog) createDialog();
 			dialog->indicateError();
 		}
@@ -127,14 +129,14 @@ qDebug("failed");
 	});
 }
 
-void RKProgressControl::dialogDestroyed () {
-	RK_TRACE (MISC);
+void RKProgressControl::dialogDestroyed() {
+	RK_TRACE(MISC);
 
 	dialog = nullptr;
 	if ((!is_done) && (mode & AllowCancel)) {
 		is_done = true;
 		if (mode & AutoCancelCommands) {
-			for (auto it = outstanding_commands.cbegin (); it != outstanding_commands.cend (); ++it) {
+			for (auto it = outstanding_commands.cbegin(); it != outstanding_commands.cend(); ++it) {
 				RInterface::instance()->cancelCommand(*it);
 			}
 		}
@@ -142,37 +144,35 @@ void RKProgressControl::dialogDestroyed () {
 	}
 }
 
-void RKProgressControl::done () {
-	RK_TRACE (MISC);
+void RKProgressControl::done() {
+	RK_TRACE(MISC);
 
 	is_done = true;
 	if (dialog) {
-		dialog->finished ();
+		dialog->finished();
 	}
 
 	if ((!modal) && autodelete) {
-		if (dialog) disconnect (dialog, &QObject::destroyed, this, &RKProgressControl::dialogDestroyed);		// we're already dead
-		deleteLater ();
+		if (dialog) disconnect(dialog, &QObject::destroyed, this, &RKProgressControl::dialogDestroyed); // we're already dead
+		deleteLater();
 	}
 }
 
-void RKProgressControl::createDialog () {
-	RK_TRACE (MISC);
+void RKProgressControl::createDialog() {
+	RK_TRACE(MISC);
 
-	dialog = new RKProgressControlDialog (text, caption, mode, modal);
-	connect (dialog, &QObject::destroyed, this, &RKProgressControl::dialogDestroyed);
-	if (is_done) done ();
-	for (int i = 0; i < output_log.count (); ++i) {
-		dialog->addOutput (&(output_log[i]));
+	dialog = new RKProgressControlDialog(text, caption, mode, modal);
+	connect(dialog, &QObject::destroyed, this, &RKProgressControl::dialogDestroyed);
+	if (is_done) done();
+	for (int i = 0; i < output_log.count(); ++i) {
+		dialog->addOutput(output_log[i]);
 	}
 }
 
-void RKProgressControl::newOutput (RCommand *, const ROutput *output) {
-	RK_TRACE (MISC);
-	RK_ASSERT (output);
+void RKProgressControl::newOutput(RCommand *, const ROutput &output) {
+	RK_TRACE(MISC);
 
-	const ROutput outputc(*output);
-	output_log.append(outputc);
+	output_log.append(output);
 	if (mode & RaiseOnOutput) {
 		if (!dialog) createDialog();
 		dialog->raise();
@@ -181,37 +181,38 @@ void RKProgressControl::newOutput (RCommand *, const ROutput *output) {
 }
 
 QString RKProgressControl::fullCommandOutput() {
-	RK_TRACE (MISC);
+	RK_TRACE(MISC);
 
 	QString ret;
-	for (const ROutput& out : std::as_const(output_log)) ret.append (out.output);
+	for (const ROutput &out : std::as_const(output_log))
+		ret.append(out.output);
 	return ret;
 }
 
 //////////////////////////// RKProgressControlDialog ///////////////////////////////////////////7
 
-#include <qlayout.h>
+#include <QPushButton>
 #include <QTextEdit>
 #include <qlabel.h>
-#include <QPushButton>
+#include <qlayout.h>
 
 #include <kstandardguiitem.h>
 
 RKProgressControlDialog::RKProgressControlDialog(const QString &text, const QString &caption, int mode_flags, bool modal) : QDialog(nullptr) {
-	RK_TRACE (MISC);
+	RK_TRACE(MISC);
 
-	setAttribute (Qt::WA_DeleteOnClose, true);
-	setModal (modal);
-	setWindowTitle (caption);
+	setAttribute(Qt::WA_DeleteOnClose, true);
+	setModal(modal);
+	setWindowTitle(caption);
 
-	QVBoxLayout *layout = new QVBoxLayout (this);
+	QVBoxLayout *layout = new QVBoxLayout(this);
 
-	QWidget *mainbox = new QWidget (this);
-	QVBoxLayout *mainboxlayout = new QVBoxLayout (mainbox);
-	mainbox->setSizePolicy (QSizePolicy::Fixed, QSizePolicy::Fixed);
-	mainboxlayout->setContentsMargins (0, 0, 0, 0);
+	QWidget *mainbox = new QWidget(this);
+	QVBoxLayout *mainboxlayout = new QVBoxLayout(mainbox);
+	mainbox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+	mainboxlayout->setContentsMargins(0, 0, 0, 0);
 
-	mainboxlayout->addWidget (RKCommonFunctions::linkedWrappedLabel (text));
+	mainboxlayout->addWidget(RKCommonFunctions::linkedWrappedLabel(text));
 
 	error_indicator = new QLabel(i18n("<b>There has been an error while running the command. See below for output details</b>"), mainbox);
 	QPalette palette = error_indicator->palette();
@@ -220,35 +221,35 @@ RKProgressControlDialog::RKProgressControlDialog(const QString &text, const QStr
 	error_indicator->hide();
 	mainboxlayout->addWidget(error_indicator);
 
-	detailsbox = new QWidget (this);
-	QVBoxLayout *detailsboxlayout = new QVBoxLayout (detailsbox);
-	detailsboxlayout->setContentsMargins (0, 0, 0, 0);
+	detailsbox = new QWidget(this);
+	QVBoxLayout *detailsboxlayout = new QVBoxLayout(detailsbox);
+	detailsboxlayout->setContentsMargins(0, 0, 0, 0);
 
 	detailsboxlayout->addWidget(new QLabel(i18n("Output")));
 
-	output_text = new QTextEdit (detailsbox);
-	output_text->setReadOnly (true);
-	output_text->setPlainText (QString ());
-	output_text->setUndoRedoEnabled (false);
-	output_text->setLineWrapMode (QTextEdit::NoWrap);
-	output_text->setMinimumWidth (QFontMetrics (output_text->font ()).averageCharWidth () * RKSettingsModuleR::getDefaultWidth ());
-	detailsboxlayout->addWidget (output_text);
-	detailsboxlayout->setStretchFactor (output_text, 10);
+	output_text = new QTextEdit(detailsbox);
+	output_text->setReadOnly(true);
+	output_text->setPlainText(QString());
+	output_text->setUndoRedoEnabled(false);
+	output_text->setLineWrapMode(QTextEdit::NoWrap);
+	output_text->setMinimumWidth(QFontMetrics(output_text->font()).averageCharWidth() * RKSettingsModuleR::getDefaultWidth());
+	detailsboxlayout->addWidget(output_text);
+	detailsboxlayout->setStretchFactor(output_text, 10);
 
-	buttons = new QDialogButtonBox (QDialogButtonBox::Cancel, this);
-	connect (buttons->button (QDialogButtonBox::Cancel), &QPushButton::clicked, this, &QDialog::reject);
+	buttons = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
+	connect(buttons->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &QDialog::reject);
 	if ((mode_flags & RKProgressControl::ShowOutput) && !(mode_flags & RKProgressControl::OutputShownByDefault)) {
-		QPushButton* button = buttons->addButton(i18n("Show Output"), QDialogButtonBox::HelpRole);
-		connect (button, &QPushButton::clicked, this, &RKProgressControlDialog::toggleDetails);
+		QPushButton *button = buttons->addButton(i18n("Show Output"), QDialogButtonBox::HelpRole);
+		connect(button, &QPushButton::clicked, this, &RKProgressControlDialog::toggleDetails);
 	}
-	if (mode_flags & RKProgressControl::AllowCancel) buttons->button (QDialogButtonBox::Cancel)->setText (i18n ("Cancel"));
-	else (setCloseTextToClose ());
+	if (mode_flags & RKProgressControl::AllowCancel) buttons->button(QDialogButtonBox::Cancel)->setText(i18n("Cancel"));
+	else (setCloseTextToClose());
 
-	detailsbox->setVisible (mode_flags & RKProgressControl::OutputShownByDefault);
+	detailsbox->setVisible(mode_flags & RKProgressControl::OutputShownByDefault);
 
-	layout->addWidget (mainbox);
-	layout->addWidget (detailsbox);
-	layout->addWidget (buttons);
+	layout->addWidget(mainbox);
+	layout->addWidget(detailsbox);
+	layout->addWidget(buttons);
 
 	prevent_close = (mode_flags & RKProgressControl::PreventClose);
 
@@ -256,8 +257,8 @@ RKProgressControlDialog::RKProgressControlDialog(const QString &text, const QStr
 	is_done = false;
 }
 
-RKProgressControlDialog::~RKProgressControlDialog () {
-	RK_TRACE (MISC);
+RKProgressControlDialog::~RKProgressControlDialog() {
+	RK_TRACE(MISC);
 }
 
 void RKProgressControlDialog::indicateError() {
@@ -266,120 +267,120 @@ void RKProgressControlDialog::indicateError() {
 	error_indicator->show();
 }
 
-void RKProgressControlDialog::addOutput (const ROutput *output) {
-	RK_TRACE (MISC);
+void RKProgressControlDialog::addOutput(const ROutput &output) {
+	RK_TRACE(MISC);
 
 	// scrolled all the way to the bottom?
 	bool at_end = true;
-	if (detailsbox->isVisible ()) {
-		QScrollBar *bar = output_text->verticalScrollBar ();
-		if (bar && (bar->value () < bar->maximum ())) at_end = false;
+	if (detailsbox->isVisible()) {
+		QScrollBar *bar = output_text->verticalScrollBar();
+		if (bar && (bar->value() < bar->maximum())) at_end = false;
 	}
 
-	if (output->type != last_output_type) {
-		last_output_type = output->type;
-		output_text->insertPlainText ("\n");
+	if (output.type != last_output_type) {
+		last_output_type = output.type;
+		output_text->insertPlainText(QStringLiteral("\n"));
 
-		if (output->type == ROutput::Output) {
+		if (output.type == ROutput::Output) {
 			output_text->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NormalText).color());
 		} else {
 			output_text->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NegativeText).color());
-			if (!detailsbox->isVisible ()) toggleDetails ();
+			if (!detailsbox->isVisible()) toggleDetails();
 		}
 	}
 
-	output_text->insertPlainText (output->output);
+	output_text->insertPlainText(output.output);
 
 	// if previously at end, auto-scroll
-	if (at_end && output_text->isVisible ()) scrollDown ();
+	if (at_end && output_text->isVisible()) scrollDown();
 }
 
-void RKProgressControlDialog::toggleDetails () {
-	RK_TRACE (MISC);
+void RKProgressControlDialog::toggleDetails() {
+	RK_TRACE(MISC);
 
-	int new_height = height ();
-	if (detailsbox->isVisible ()) {
-		new_height -= detailsbox->height ();
-		detailsbox->hide ();
+	int new_height = height();
+	if (detailsbox->isVisible()) {
+		new_height -= detailsbox->height();
+		detailsbox->hide();
 	} else {
-		int h = detailsbox->height ();
-		if (h <= 0) h = detailsbox->sizeHint ().height ();
+		int h = detailsbox->height();
+		if (h <= 0) h = detailsbox->sizeHint().height();
 		new_height += h;
-		detailsbox->show ();
-		scrollDown ();
+		detailsbox->show();
+		scrollDown();
 	}
 
-	layout ()->activate ();
-	resize (width (), new_height);
+	layout()->activate();
+	resize(width(), new_height);
 }
 
-void RKProgressControlDialog::scrollDown () {
-	RK_TRACE (MISC);
+void RKProgressControlDialog::scrollDown() {
+	RK_TRACE(MISC);
 
-	QScrollBar *bar = output_text->verticalScrollBar ();
-	if (bar) bar->setValue (bar->maximum ());
+	QScrollBar *bar = output_text->verticalScrollBar();
+	if (bar) bar->setValue(bar->maximum());
 }
 
-void RKProgressControlDialog::setCloseTextToClose () {
-	RK_TRACE (MISC);
+void RKProgressControlDialog::setCloseTextToClose() {
+	RK_TRACE(MISC);
 
-	buttons->removeButton (buttons->button (QDialogButtonBox::Cancel));
-	QPushButton *done_button = buttons->addButton (QDialogButtonBox::Ok);
-	done_button->setText (i18n ("Done"));
-	connect (done_button, &QPushButton::clicked, this, &QDialog::reject);
+	buttons->removeButton(buttons->button(QDialogButtonBox::Cancel));
+	QPushButton *done_button = buttons->addButton(QDialogButtonBox::Ok);
+	done_button->setText(i18n("Done"));
+	connect(done_button, &QPushButton::clicked, this, &QDialog::reject);
 }
 
-void RKProgressControlDialog::finished () {
-	RK_TRACE (MISC);
+void RKProgressControlDialog::finished() {
+	RK_TRACE(MISC);
 
 	is_done = true;
-	setCloseTextToClose ();
-	if (!detailsbox->isVisible ()) reject ();
+	setCloseTextToClose();
+	if (!detailsbox->isVisible()) reject();
 }
 
-void RKProgressControlDialog::closeEvent (QCloseEvent *e) {
-	RK_TRACE (DIALOGS);
+void RKProgressControlDialog::closeEvent(QCloseEvent *e) {
+	RK_TRACE(DIALOGS);
 
 	if (prevent_close && (!is_done)) {
-		e->ignore ();
+		e->ignore();
 	} else {
-		QDialog::closeEvent (e);
+		QDialog::closeEvent(e);
 	}
 }
 
-#include <KMessageWidget>
 #include <KMessageBox>
+#include <KMessageWidget>
 #include <KStandardAction>
 
 #include "../windows/rkmdiwindow.h"
 #include "rkstandardicons.h"
 
 RKInlineProgressControl::RKInlineProgressControl(QWidget *display_area, bool allow_cancel) : QObject(display_area),
-						autoclose(false),
-						allow_cancel(allow_cancel),
-						is_done(false),
-						any_failed(false),
-						display_area(display_area),
-						prevent_close_message(nullptr),
-						close_action(nullptr) {
+                                                                                             autoclose(false),
+                                                                                             allow_cancel(allow_cancel),
+                                                                                             is_done(false),
+                                                                                             any_failed(false),
+                                                                                             display_area(display_area),
+                                                                                             prevent_close_message(nullptr),
+                                                                                             close_action(nullptr) {
 	RK_TRACE(MISC);
 
-	QWidget* logical_parent = display_area;
-	while(logical_parent->parentWidget() && !(logical_parent->isWindow() || qobject_cast<RKMDIWindow*>(logical_parent))) {
+	QWidget *logical_parent = display_area;
+	while (logical_parent->parentWidget() && !(logical_parent->isWindow() || qobject_cast<RKMDIWindow *>(logical_parent))) {
 		logical_parent = logical_parent->parentWidget();
 	}
 	logical_parent->installEventFilter(this);
-	//display_area->installEventFilter(this);
+	// display_area->installEventFilter(this);
 
 	wrapper = new QWidget(display_area);
 	wrapper->setAutoFillBackground(true);
 	auto layout = new QVBoxLayout(wrapper);
-	layout->setContentsMargins(0,0,0,0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	layout->setSpacing(0);
 	message_widget = new KMessageWidget();
 	message_widget->setPosition(KMessageWidget::Position::Header);
 	message_widget->setWordWrap(true);
-	message_widget->setCloseButtonVisible(false);  // we want a button, instead, for consistency with cancel
+	message_widget->setCloseButtonVisible(false); // we want a button, instead, for consistency with cancel
 	if (allow_cancel) {
 		setCloseAction(i18n("Cancel"));
 	}
@@ -428,12 +429,12 @@ void RKInlineProgressControl::addRCommand(RCommand *command) {
 			done();
 		}
 	});
-	connect(command->notifier(), &RCommandNotifier:: commandOutput, this, [this](RCommand *, const ROutput *o) {
-		addOutput(o->output, o->type != ROutput::Output);
+	connect(command->notifier(), &RCommandNotifier::commandOutput, this, [this](RCommand *, const ROutput &o) {
+		addOutput(o.output, o.type != ROutput::Output);
 	});
 }
 
-void RKInlineProgressControl::addOutput(const QString& output, bool is_error_warning) {
+void RKInlineProgressControl::addOutput(const QString &output, bool is_error_warning) {
 	RK_TRACE(MISC);
 	if (is_error_warning) {
 		output_display->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NegativeText).color());
@@ -449,15 +450,15 @@ void RKInlineProgressControl::done() {
 		deleteLater();
 	} else {
 		message_widget->setMessageType(any_failed ? KMessageWidget::Error : KMessageWidget::Positive);
-		message_widget->setText(text + ' ' + (any_failed ? i18n("<b>An error occurred</b> (see below for details)") : i18n("<b>Done</b>")));
-		message_widget->setIcon(QIcon::fromTheme(any_failed ? "emblem-error" : "emblem-success"));
+		message_widget->setText(text + u' ' + (any_failed ? i18n("<b>An error occurred</b> (see below for details)") : i18n("<b>Done</b>")));
+		message_widget->setIcon(QIcon::fromTheme(any_failed ? u"emblem-error"_s : u"emblem-success"_s));
 		message_widget->animatedShow(); // to force an update of geometry
 		setCloseAction(i18n("Close"));
 	}
 	is_done = true;
 }
 
-void RKInlineProgressControl::setText(const QString& _text){
+void RKInlineProgressControl::setText(const QString &_text) {
 	RK_TRACE(MISC);
 	text = _text;
 	message_widget->setText(text);
@@ -486,7 +487,7 @@ bool RKInlineProgressControl::eventFilter(QObject *w, QEvent *e) {
 	}
 	if ((e->type() == QEvent::Close) && !is_done) {
 		if (allow_cancel) {
-			bool autoclose_save = autoclose;  // must prevent self-destruction while dialog below is active (the operation might complete, while it exec's)
+			bool autoclose_save = autoclose; // must prevent self-destruction while dialog below is active (the operation might complete, while it exec's)
 			autoclose = false;
 
 			bool ignore = (KMessageBox::warningContinueCancel(display_area, i18n("Closing this window will cancel the current operation. Are you sure?"), i18n("Cancel operation"), KGuiItem(i18n("Keep waiting")), KGuiItem(i18n("Cancel && Close"))) == KMessageBox::Continue);
@@ -513,5 +514,3 @@ bool RKInlineProgressControl::eventFilter(QObject *w, QEvent *e) {
 	}
 	return false;
 }
-
-
