@@ -14,7 +14,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "../debug.h"
 
-RKPasteSpecialAction::RKPasteSpecialAction(QObject* parent) : QAction(parent) {
+RKPasteSpecialAction::RKPasteSpecialAction(QObject *parent) : QAction(parent) {
 	RK_TRACE(MISC);
 
 	setText(i18n("Paste special..."));
@@ -30,13 +30,13 @@ void RKPasteSpecialAction::doSpecialPaste() {
 
 	QWidget *pwin = nullptr;
 	const auto objs = associatedObjects();
-	for(auto obj : objs) {
-		if (qobject_cast<QWidget*>(obj)) {
-			pwin = static_cast<QWidget*>(obj);
+	for (auto obj : objs) {
+		if (qobject_cast<QWidget *>(obj)) {
+			pwin = static_cast<QWidget *>(obj);
 			break;
 		}
 	}
-	RKPasteSpecialDialog* dialog = new RKPasteSpecialDialog(pwin);
+	RKPasteSpecialDialog *dialog = new RKPasteSpecialDialog(pwin);
 	int res = dialog->exec();
 	if (res == QDialog::Accepted) {
 		Q_EMIT pasteText(dialog->resultingText());
@@ -44,36 +44,36 @@ void RKPasteSpecialAction::doSpecialPaste() {
 	dialog->deleteLater();
 }
 
+#include <QApplication>
 #include <QCheckBox>
-#include <QVBoxLayout>
+#include <QClipboard>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLineEdit>
-#include <QApplication>
-#include <QClipboard>
 #include <QMimeData>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
-#include "../dataeditor/rktextmatrix.h"
 #include "../core/robject.h"
-#include "rksaveobjectchooser.h"
-#include "../rbackend/rkrinterface.h"
+#include "../dataeditor/rktextmatrix.h"
 #include "../misc/rkprogresscontrol.h"
 #include "../misc/rkradiogroup.h"
+#include "../rbackend/rkrinterface.h"
+#include "rksaveobjectchooser.h"
 
-RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : QDialog(parent) {
-	RK_TRACE (MISC);
+RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget *parent, bool standalone) : QDialog(parent) {
+	RK_TRACE(MISC);
 
-	setWindowTitle (i18n ("Paste Special..."));
+	setWindowTitle(i18n("Paste Special..."));
 
-	QVBoxLayout *pagelayout = new QVBoxLayout (this);
+	QVBoxLayout *pagelayout = new QVBoxLayout(this);
 	objectname = standalone ? new RKSaveObjectChooser(this, QStringLiteral("pasted.data")) : nullptr;
 	if (objectname) {
 		connect(objectname, &RKSaveObjectChooser::changed, this, &RKPasteSpecialDialog::updateState);
 		pagelayout->addWidget(objectname);
 	}
-	QHBoxLayout *rowlayout = new QHBoxLayout ();
-	pagelayout->addLayout (rowlayout);
+	QHBoxLayout *rowlayout = new QHBoxLayout();
+	pagelayout->addLayout(rowlayout);
 
 	// Mode box
 	auto box = new RKRadioGroup(i18n("Paste Mode"));
@@ -81,26 +81,27 @@ RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : Q
 	box->addButton(i18n("Single string"), DimSingleString);
 	box->addButton(i18n("Vector"), DimVector);
 	box->addButton(i18n("Matrix"), DimMatrix);
-	box->addButton(i18n("data.frame"), DimDataFrame)->setChecked(true);;
-	connect (dimensionality_group, &QButtonGroup::idClicked, this, &RKPasteSpecialDialog::updateState);
-	rowlayout->addWidget (box);
+	box->addButton(i18n("data.frame"), DimDataFrame)->setChecked(true);
+	;
+	connect(dimensionality_group, &QButtonGroup::idClicked, this, &RKPasteSpecialDialog::updateState);
+	rowlayout->addWidget(box);
 
-	const QMimeData* clipdata = QApplication::clipboard ()->mimeData ();
+	const QMimeData *clipdata = QApplication::clipboard()->mimeData();
 
 	// Separator box
 	box = new RKRadioGroup(i18n("Field Separator"));
 	separator_group = box->group();
 	box->addButton(i18n("Tab"), SepTab)->setChecked(true); // tab-separated is a reasonable fallback guess
-	box->addButton(i18n("Comma"), SepComma)->setChecked(clipdata->hasFormat ("text/comma-separated-values"));
+	box->addButton(i18n("Comma"), SepComma)->setChecked(clipdata->hasFormat(QStringLiteral("text/comma-separated-values")));
 	box->addButton(i18n("Single space"), SepSpace);
 	box->addButton(i18n("Any whitespace"), SepWhitespace);
-	separator_freefield = new QLineEdit(";", box);
+	separator_freefield = new QLineEdit(QStringLiteral(";"), box);
 	box->addButton(i18n("Other:"), SepCustom, separator_freefield, QBoxLayout::LeftToRight);
 	connect(separator_group, &QButtonGroup::idClicked, this, &RKPasteSpecialDialog::updateState);
 	rowlayout->addWidget(box);
 
 	rowlayout = new QHBoxLayout;
-	pagelayout->addLayout (rowlayout);
+	pagelayout->addLayout(rowlayout);
 
 	// Quoting box
 	box = new RKRadioGroup(i18n("Quoting"));
@@ -134,28 +135,28 @@ RKPasteSpecialDialog::RKPasteSpecialDialog(QWidget* parent, bool standalone) : Q
 	group_layout->addWidget(insert_nas_box);
 	rowlayout->addWidget(box);
 
-	QDialogButtonBox *buttons = new QDialogButtonBox (QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+	QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
 	ok_button = buttons->button(QDialogButtonBox::Ok);
 	connect(ok_button, &QPushButton::clicked, this, &QDialog::accept);
-	connect(buttons->button (QDialogButtonBox::Cancel), &QPushButton::clicked, this, &QDialog::reject);
-	pagelayout->addWidget (buttons);
+	connect(buttons->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &QDialog::reject);
+	pagelayout->addWidget(buttons);
 
-	updateState ();		// initialize
+	updateState(); // initialize
 }
 
-RKPasteSpecialDialog::~RKPasteSpecialDialog () {
-	RK_TRACE (MISC);
+RKPasteSpecialDialog::~RKPasteSpecialDialog() {
+	RK_TRACE(MISC);
 }
 
-void RKPasteSpecialDialog::updateState () {
-	RK_TRACE (MISC);
+void RKPasteSpecialDialog::updateState() {
+	RK_TRACE(MISC);
 
-	int dimensionality = dimensionality_group->checkedId ();
-	
-	static_cast<QWidget*> (separator_group->parent ())->setEnabled (dimensionality != DimSingleString);
-	reverse_h_box->setEnabled (dimensionality != DimSingleString);
-	reverse_v_box->setEnabled (dimensionality >= DimMatrix);
-	insert_nas_box->setEnabled (dimensionality != DimSingleString);
+	int dimensionality = dimensionality_group->checkedId();
+
+	static_cast<QWidget *>(separator_group->parent())->setEnabled(dimensionality != DimSingleString);
+	reverse_h_box->setEnabled(dimensionality != DimSingleString);
+	reverse_v_box->setEnabled(dimensionality >= DimMatrix);
+	insert_nas_box->setEnabled(dimensionality != DimSingleString);
 	transpose_box->setEnabled(dimensionality >= DimMatrix);
 	names_box->setEnabled(dimensionality == DimDataFrame);
 	rownames_box->setEnabled(dimensionality == DimDataFrame);
@@ -163,108 +164,108 @@ void RKPasteSpecialDialog::updateState () {
 	ok_button->setEnabled((objectname == nullptr) || objectname->isOk());
 }
 
-QString RKPasteSpecialDialog::resultingText () {
-	RK_TRACE (MISC);
+QString RKPasteSpecialDialog::resultingText() {
+	RK_TRACE(MISC);
 
-	const int sep = separator_group->checkedId ();		// for easier typing
-	const int dim = dimensionality_group->checkedId ();
-	const bool reverse_h = reverse_h_box->isChecked () && (dim != DimSingleString);
-	const bool reverse_v = reverse_v_box->isChecked () && (dim >= DimMatrix);
-	const bool transpose = transpose_box->isChecked () && (dim >= DimMatrix);
+	const int sep = separator_group->checkedId(); // for easier typing
+	const int dim = dimensionality_group->checkedId();
+	const bool reverse_h = reverse_h_box->isChecked() && (dim != DimSingleString);
+	const bool reverse_v = reverse_v_box->isChecked() && (dim >= DimMatrix);
+	const bool transpose = transpose_box->isChecked() && (dim >= DimMatrix);
 	const bool names = names_box->isChecked() && (dim == DimDataFrame);
 	const bool rownames = rownames_box->isChecked() && (dim == DimDataFrame);
-	Quoting quot = (Quoting) quoting_group->checkedId();
+	Quoting quot = (Quoting)quoting_group->checkedId();
 
 	QString clip;
 
-	const QMimeData* data = QApplication::clipboard ()->mimeData ();
-	if ((dim != DimSingleString) && (sep == SepTab) && data->hasFormat ("text/tab-separated-values")) {
-		clip = QString::fromLocal8Bit (data->data ("text/tab-separated-values"));
-	} else if ((dim != DimSingleString) && (sep == SepComma) && data->hasFormat ("text/comma-separated-values")) {
-		clip = QString::fromLocal8Bit (data->data ("text/comma-separated-values"));
+	const QMimeData *data = QApplication::clipboard()->mimeData();
+	if ((dim != DimSingleString) && (sep == SepTab) && data->hasFormat(QStringLiteral("text/tab-separated-values"))) {
+		clip = QString::fromLocal8Bit(data->data(QStringLiteral("text/tab-separated-values")));
+	} else if ((dim != DimSingleString) && (sep == SepComma) && data->hasFormat(QStringLiteral("text/comma-separated-values"))) {
+		clip = QString::fromLocal8Bit(data->data(QStringLiteral("text/comma-separated-values")));
 	} else {
-		clip = data->text ();
+		clip = data->text();
 	}
 
 	if (dim == DimSingleString) return prepString(clip, quot);
 
 	QRegularExpression fieldsep;
-	if (sep == SepCustom) fieldsep.setPattern (separator_freefield->text ());
-	else if (sep == SepWhitespace) fieldsep.setPattern ("\\s+");
-	else if (sep == SepSpace) fieldsep.setPattern (" ");
-	else if (sep == SepTab) fieldsep.setPattern ("\t");
-	else if (sep == SepComma) fieldsep.setPattern ("\\,");
-	else RK_ASSERT (false);
+	if (sep == SepCustom) fieldsep.setPattern(separator_freefield->text());
+	else if (sep == SepWhitespace) fieldsep.setPattern(QStringLiteral("\\s+"));
+	else if (sep == SepSpace) fieldsep.setPattern(QStringLiteral(" "));
+	else if (sep == SepTab) fieldsep.setPattern(QStringLiteral("\t"));
+	else if (sep == SepComma) fieldsep.setPattern(QStringLiteral("\\,"));
+	else RK_ASSERT(false);
 
-	RKTextMatrix matrix = RKTextMatrix::matrixFromSeparatedValues (clip, fieldsep);
+	RKTextMatrix matrix = RKTextMatrix::matrixFromSeparatedValues(clip, fieldsep);
 	if (dim == DimVector) {
 		// transform list to single row matrix. This is wasteful on resources, but easy to code...
 		QStringList list;
-		for (int i = 0; i < matrix.numRows (); ++i) {
-			list += matrix.getRow (i);
+		for (int i = 0; i < matrix.numRows(); ++i) {
+			list += matrix.getRow(i);
 		}
-		matrix = RKTextMatrix::matrixFromSeparatedValues (list.join ("\t"));
+		matrix = RKTextMatrix::matrixFromSeparatedValues(list.join(QStringLiteral("\t")));
 	}
 
-	if (reverse_h || reverse_v || transpose) matrix = matrix.transformed (reverse_h, reverse_v, transpose);
+	if (reverse_h || reverse_v || transpose) matrix = matrix.transformed(reverse_h, reverse_v, transpose);
 
 	QString ret;
-	if (dim == DimDataFrame) ret.append("data.frame(");
-	if (dim >= DimMatrix) ret.append ("cbind(\n");
-	else ret.append ("c(");	// DimVector
+	if (dim == DimDataFrame) ret.append(u"data.frame("_s);
+	if (dim >= DimMatrix) ret.append(u"cbind(\n"_s);
+	else ret.append(u"c("_s); // DimVector
 
 	int startcol = rownames ? 1 : 0;
 	int startrow = names ? 1 : 0;
-	for (int i = startcol; i < matrix.numColumns (); ++i) {
+	for (int i = startcol; i < matrix.numColumns(); ++i) {
 		if (dim >= DimMatrix) {
-			if (i != startcol) ret.append ("),\n");
+			if (i != startcol) ret.append(u"),\n"_s);
 			if (names) {
-				ret.append(prepString(matrix.getText(0, i), QuoteAll) + "=c(");
+				ret.append(prepString(matrix.getText(0, i), QuoteAll) + u"=c("_s);
 			} else {
-				ret.append("c(");
+				ret.append(u"c("_s);
 			}
-		} else if (i != 0) ret.append (",");
+		} else if (i != 0) ret.append(u',');
 
-		for (int j = startrow; j < matrix.numRows (); ++j) {
-			if (j != startrow) ret.append (",");
+		for (int j = startrow; j < matrix.numRows(); ++j) {
+			if (j != startrow) ret.append(u',');
 			ret.append(prepString(matrix.getText(j, i), quot));
 		}
 	}
-	ret.append (")\n");
+	ret.append(u")\n"_s);
 	if (dim == DimDataFrame) {
-		ret.append(')');
+		ret.append(u')');
 		if (rownames) {
-			ret.append(", rownames=c(\n");
+			ret.append(u", rownames=c(\n"_s);
 			for (int row = startrow; row < matrix.numRows(); ++row) {
-				if (row != startrow) ret.append (",");
+				if (row != startrow) ret.append(u',');
 				ret.append(prepString(matrix.getText(row, 0), QuoteAll));
 			}
-			ret.append(")\n");
+			ret.append(u")\n"_s);
 		}
 	}
-	if (dim >= DimMatrix) ret.append (")\n");
+	if (dim >= DimMatrix) ret.append(u")\n"_s);
 
 	return (ret);
 }
 
-QString RKPasteSpecialDialog::prepString(const QString& src, const Quoting quot) const {
-//	RK_TRACE (MISC);
+QString RKPasteSpecialDialog::prepString(const QString &src, const Quoting quot) const {
+	//	RK_TRACE (MISC);
 
-	if (quot == QuoteAll) return (RObject::rQuote (src));
-	if (src.isEmpty() && insert_nas_box->isChecked ()) return ("NA");
+	if (quot == QuoteAll) return (RObject::rQuote(src));
+	if (src.isEmpty() && insert_nas_box->isChecked()) return (u"NA"_s);
 	if (quot == QuoteNone) return (src);
-	RK_ASSERT (quot == QuoteAuto);
+	RK_ASSERT(quot == QuoteAuto);
 
 	bool numeric = false;
-	src.toDouble (&numeric);	// side-effect of setting numeric to true, if number conversion succeeds
-	if (!numeric) return (RObject::rQuote (src));
+	src.toDouble(&numeric); // side-effect of setting numeric to true, if number conversion succeeds
+	if (!numeric) return (RObject::rQuote(src));
 	return src;
 }
 
 void RKPasteSpecialDialog::accept() {
 	RK_TRACE(MISC);
 	if (objectname) {
-		RCommand *command = new RCommand(objectname->currentFullName() + " <- " + resultingText(), RCommand::App | RCommand::ObjectListUpdate);
+		RCommand *command = new RCommand(objectname->currentFullName() + u" <- "_s + resultingText(), RCommand::App | RCommand::ObjectListUpdate);
 		connect(command->notifier(), &RCommandNotifier::commandFinished, [](RCommand *c) {
 			if (c->failed()) {
 				QString msg = c->fullOutput();
