@@ -9,9 +9,9 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "rkcomponent.h"
 
-#include <qstring.h>
-#include <QHash>
 #include "../core/robject.h"
+#include <QHash>
+#include <qstring.h>
 
 class QPushButton;
 class QButtonGroup;
@@ -25,24 +25,24 @@ class QTreeWidgetItem;
 @author Thomas Friedrichsmeier
 */
 class RKFormula : public RKComponent {
-  Q_OBJECT
-public:
-	RKFormula (const QDomElement &element, RKComponent *parent_component, QWidget *parent_widget);
-	~RKFormula ();
+	Q_OBJECT
+  public:
+	RKFormula(const QDomElement &element, RKComponent *parent_component, QWidget *parent_widget);
+	~RKFormula();
 
-	QVariant value (const QString &modifier=QString ()) override { return model->value (modifier); };
-	QStringList getUiLabelPair () const override;
-	bool isValid () override;
+	QVariant value(const QString &modifier = QString()) override { return model->value(modifier); };
+	QStringList getUiLabelPair() const override;
+	bool isValid() override;
 
-/** RTTI */
-	int type () override { return ComponentFormula; };
-public Q_SLOTS:
-	void typeChange (int id);
-	void addButtonClicked ();
-	void removeButtonClicked ();
-	void factorsChanged (RKComponentPropertyBase *);
+	/** RTTI */
+	int type() override { return ComponentFormula; };
+  public Q_SLOTS:
+	void typeChange(int id);
+	void addButtonClicked();
+	void removeButtonClicked();
+	void factorsChanged(RKComponentPropertyBase *);
 
-private:
+  private:
 	RKComponentPropertyRObjects *fixed_factors;
 	RKComponentPropertyRObjects *dependent;
 	RKComponentPropertyBase *model;
@@ -51,13 +51,15 @@ private:
 
 	bool multitable;
 	bool model_ok;
-	typedef QMap<QString, RObject*> MangledNames;
+	typedef QMap<QString, RObject *> MangledNames;
 	MangledNames mangled_names;
 
-	enum ModelType { FullModel=0, MainEffects=1, Custom=2 };
+	enum ModelType { FullModel = 0,
+		             MainEffects = 1,
+		             Custom = 2 };
 	ModelType model_type;
 	QButtonGroup *type_selector;
-	
+
 	QWidget *custom_model_widget;
 	QTreeWidget *model_view;
 	QTreeWidget *predictors_view;
@@ -65,24 +67,24 @@ private:
 	QPushButton *remove_button;
 	QSpinBox *level_box;
 	QString label_string;
-	
-	void checkCustomModel ();
-	void makeModelString ();
-	QString mangleName (RObject *var);
-	
-	typedef QHash<QTreeWidgetItem*, RObject*> ItemMap;
+
+	void checkCustomModel();
+	void makeModelString();
+	QString mangleName(RObject *var);
+
+	typedef QHash<QTreeWidgetItem *, RObject *> ItemMap;
 	ItemMap predictors_map;
-	
+
 	struct Interaction {
 		int level;
 		RObject::ObjectList vars;
 	};
-	
-	typedef QHash<QTreeWidgetItem*, Interaction> InteractionMap;
+
+	typedef QHash<QTreeWidgetItem *, Interaction> InteractionMap;
 	InteractionMap interaction_map;
-	
+
 	/** recursively cross the given source variables on level level. Returns the resulting terms in an QList */
-	QList<Interaction> makeInteractions (int level, RObject::ObjectList);
+	QList<Interaction> makeInteractions(int level, RObject::ObjectList);
 };
 
 #endif
