@@ -3,7 +3,6 @@ SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemai
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
-function calculate () {
-	echo ('setwd("' + getValue ("dir") + '")\n');
+function calculate() {
+	echo(`setwd("${getValue("dir")}")\n`);
 }
-
