@@ -1,3 +1,7 @@
+# - This file is part of the RKWard project (https://rkward.kde.org).
+# SPDX-FileCopyrightText: by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+# SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+# SPDX-License-Identifier: GPL-2.0-or-later
 #' Sync R object(s)
 #' 
 #' RKWard keeps an internal representation of objects in the R workspace. For
@@ -21,20 +25,20 @@
 #' @seealso \url{rkward://page/rkward_workspace_browser}
 #' @keywords utilities misc
 #' @rdname rk.sync
-#' @examples
-#' 
-#' rk.sync (rkward::rk.record.plot)
-#' 
 # should this really be public?
 #' @export
+#' @examples
+#' \dontrun{
+#' rk.sync (rkward::rk.record.plot)
+#' }
 "rk.sync" <- function (x) {
 	object <- deparse (substitute (x))
-	.rk.do.call("sync", list(NULL, NULL, object))
+	.rk.call.nested("sync", list(NULL, NULL, object))
 }
 
 # should this really be public?
 #' @export
 #' @rdname rk.sync
 "rk.sync.global" <- function () {
-	.rk.do.call("sync", rk.check.env.changes(globalenv()))
+	.rk.call.nested("sync", rk.check.env.changes(globalenv()))
 }
