@@ -6,72 +6,72 @@ SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "rksettingsmoduler.h"
 
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <KConfigGroup>
 #include <KUrlRequester>
 
-#include <qlabel.h>
+#include <QDialogButtonBox>
+#include <QGridLayout>
+#include <QInputDialog>
+#include <QPushButton>
+#include <QSpinBox>
+#include <QTextEdit>
+#include <QVBoxLayout>
 #include <qcheckbox.h>
 #include <qcombobox.h>
+#include <qlabel.h>
 #include <qlineedit.h>
-#include <QVBoxLayout>
-#include <QGridLayout>
-#include <QPushButton>
-#include <QTextEdit>
-#include <QDialogButtonBox>
-#include <QSpinBox>
-#include <QInputDialog>
 
-#include "rksettingsmodulegeneral.h"
-#include "rksettingsmoduleplugins.h"
 #include "../core/robject.h"
 #include "../dialogs/rksetupwizard.h"
 #include "../misc/multistringselector.h"
-#include "../misc/rkprogresscontrol.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkprogresscontrol.h"
 #include "../misc/rkspinbox.h"
 #include "../misc/rkstandardicons.h"
+#include "../misc/rkstyle.h"
+#include "../plugin/rkcomponentmap.h"
 #include "../rbackend/rkrinterface.h"
 #include "../rbackend/rksessionvars.h"
-#include "../plugin/rkcomponentmap.h"
-#include "../misc/rkstyle.h"
 #include "rksettings.h"
+#include "rksettingsmodulegeneral.h"
+#include "rksettingsmoduleplugins.h"
 
 #include "../debug.h"
 
 // static constants
-QString RKSettingsModuleR::builtin_editor = "<rkward>";
+QString RKSettingsModuleR::builtin_editor = QStringLiteral("<rkward>");
 // session constants
 QString RKSettingsModuleR::help_base_url;
 // static members
-RKConfigValue<QString> RKSettingsModuleR::options_outdec {"OutDec", "."};
-RKConfigValue<int> RKSettingsModuleR::options_width {"width", 80};
-RKConfigValue<int> RKSettingsModuleR::options_warn {"warn", 0};
-RKConfigValue<int> RKSettingsModuleR::options_warningslength {"warnings.length", 1000};
-RKConfigValue<int> RKSettingsModuleR::options_maxprint {"max.print", 99999};
-RKConfigValue<bool> RKSettingsModuleR::options_keepsource {"keep.source", true};
-RKConfigValue<bool> RKSettingsModuleR::options_keepsourcepkgs {"keep.source.pkgs", false};
-RKConfigValue<int> RKSettingsModuleR::options_expressions {"expressions", 5000};
-RKConfigValue<int> RKSettingsModuleR::options_digits {"digits", 7};
-RKConfigValue<bool> RKSettingsModuleR::options_checkbounds {"check.bounds", false};
-RKConfigValue<QString> RKSettingsModuleR::options_editor {"editor", builtin_editor};
-RKConfigValue<QString> RKSettingsModuleR::options_pager {"pager", builtin_editor};
-RKConfigValue<QString> RKSettingsModuleR::options_further {"further init commands", QString()};
-RKConfigValue<QStringList> RKSettingsModuleR::options_addpaths {"addsyspaths", QStringList()};
-RKConfigValue<QString> RKSettingsModuleR::options_r_binary {"user configured R binary", QString()};
+RKConfigValue<QString> RKSettingsModuleR::options_outdec{"OutDec", QStringLiteral(".")};
+RKConfigValue<int> RKSettingsModuleR::options_width{"width", 80};
+RKConfigValue<int> RKSettingsModuleR::options_warn{"warn", 0};
+RKConfigValue<int> RKSettingsModuleR::options_warningslength{"warnings.length", 1000};
+RKConfigValue<int> RKSettingsModuleR::options_maxprint{"max.print", 99999};
+RKConfigValue<bool> RKSettingsModuleR::options_keepsource{"keep.source", true};
+RKConfigValue<bool> RKSettingsModuleR::options_keepsourcepkgs{"keep.source.pkgs", false};
+RKConfigValue<int> RKSettingsModuleR::options_expressions{"expressions", 5000};
+RKConfigValue<int> RKSettingsModuleR::options_digits{"digits", 7};
+RKConfigValue<bool> RKSettingsModuleR::options_checkbounds{"check.bounds", false};
+RKConfigValue<QString> RKSettingsModuleR::options_editor{"editor", builtin_editor};
+RKConfigValue<QString> RKSettingsModuleR::options_pager{"pager", builtin_editor};
+RKConfigValue<QString> RKSettingsModuleR::options_further{"further init commands", QString()};
+RKConfigValue<QStringList> RKSettingsModuleR::options_addpaths{"addsyspaths", QStringList()};
+RKConfigValue<QString> RKSettingsModuleR::options_r_binary{"user configured R binary", QString()};
 
 class RKSettingsPageR : public RKSettingsModuleWidget {
-public:
-	RKSettingsPageR(QWidget* parent, RKSettingsModule *parent_module) : RKSettingsModuleWidget(parent, parent_module, RKSettingsModuleR::page_id) {
+  public:
+	RKSettingsPageR(QWidget *parent, RKSettingsModule *parent_module) : RKSettingsModuleWidget(parent, parent_module, RKSettingsModuleR::page_id) {
 		RK_TRACE(SETTINGS);
 
 		setWindowTitle(i18n("R-Backend"));
-		setWindowIcon(QIcon::fromTheme("emblem-system-symbolic"));
+		setWindowIcon(QIcon::fromTheme(QStringLiteral("emblem-system-symbolic")));
 
 		QVBoxLayout *main_vbox = new QVBoxLayout(this);
 
-		main_vbox->addSpacing(2*RKStyle::spacingHint());
+		main_vbox->addSpacing(2 * RKStyle::spacingHint());
 
 		main_vbox->addWidget(RKCommonFunctions::wordWrappedLabel(i18n("The following settings mostly affect R behavior in the console. It is generally safe to keep these unchanged.")));
 
@@ -82,8 +82,8 @@ public:
 		// options (warn)
 		grid->addWidget(new QLabel(i18n("Display warnings")), ++row, 0);
 		auto warn_input = RKSettingsModuleR::options_warn.makeDropDown(RKConfigBase::LabelList(
-			{{-1, i18n("Suppress warnings")}, {0, i18n("Print warnings later (default)")}, {1, i18n("Print warnings immediately")}, {2, i18n ("Convert warnings to errors")}}
-		), this);
+		                                                                   {{-1, i18n("Suppress warnings")}, {0, i18n("Print warnings later (default)")}, {1, i18n("Print warnings immediately")}, {2, i18n("Convert warnings to errors")}}),
+		                                                               this);
 		grid->addWidget(warn_input, row, 1);
 
 		// options (OutDec)
@@ -127,7 +127,7 @@ public:
 		auto checkbounds_input = RKSettingsModuleR::options_checkbounds.makeDropDown(RKConfigBase::LabelList({{1, i18n("TRUE")}, {0, i18n("FALSE (default)")}}), this);
 		grid->addWidget(checkbounds_input, row, 1);
 
-		grid->addWidget (new QLabel(i18n("Editor command"), this), ++row, 0);
+		grid->addWidget(new QLabel(i18n("Editor command"), this), ++row, 0);
 		editor_input = new QComboBox(this);
 		editor_input->setEditable(true);
 		editor_input->addItem(RKSettingsModuleR::builtin_editor);
@@ -149,7 +149,7 @@ public:
 		connect(pager_input, &QComboBox::editTextChanged, this, &RKSettingsPageR::change);
 		grid->addWidget(pager_input, row, 1);
 
-		grid->addWidget(new QLabel(i18n ("Further (option) commands to run in each session"), this), ++row, 0, 1, 2);
+		grid->addWidget(new QLabel(i18n("Further (option) commands to run in each session"), this), ++row, 0, 1, 2);
 		further_input = new QTextEdit(this);
 		further_input->setWordWrapMode(QTextOption::NoWrap);
 		further_input->setAcceptRichText(false);
@@ -162,11 +162,11 @@ public:
 		addpaths_selector = new MultiStringSelector(i18n("Addition search paths for utilities used by R"), this);
 		addpaths_selector->setValues(RKSettingsModuleR::options_addpaths);
 		connect(addpaths_selector, &MultiStringSelector::listChanged, this, &RKSettingsPageR::change);
-		connect(addpaths_selector, &MultiStringSelector::getNewStrings, this, [this](QStringList* string_list) {
+		connect(addpaths_selector, &MultiStringSelector::getNewStrings, this, [this](QStringList *string_list) {
 			QDialog dialog(this);
 			dialog.setWindowTitle(i18n("Add System Path Directory"));
 			QVBoxLayout *layout = new QVBoxLayout(&dialog);
-			layout->addWidget (RKCommonFunctions::wordWrappedLabel(i18n("Specify or select directory to add to the system file path of the running R session")));
+			layout->addWidget(RKCommonFunctions::wordWrappedLabel(i18n("Specify or select directory to add to the system file path of the running R session")));
 
 			KUrlRequester *req = new KUrlRequester();
 			req->setMode(KFile::Directory);
@@ -205,7 +205,8 @@ public:
 			RInterface::issueCommand(new RCommand(*it, RCommand::App), parentModule()->commandChain());
 		}
 	}
-private:
+
+  private:
 	QComboBox *editor_input;
 	QComboBox *pager_input;
 	QTextEdit *further_input;
@@ -217,51 +218,51 @@ RKSettingsModuleR::RKSettingsModuleR(QObject *parent) : RKSettingsModule(parent)
 }
 
 RKSettingsModuleR::~RKSettingsModuleR() {
-	RK_TRACE (SETTINGS);
+	RK_TRACE(SETTINGS);
 }
 
 void RKSettingsModuleR::createPages(RKSettings *parent) {
 	parent->addSettingsPage(new RKSettingsPageR(parent, this));
 }
 
-static QLatin1String RTrueFalse(bool val) {
-	if (val) return QLatin1String("TRUE");
-	return QLatin1String("FALSE");
+static QString RTrueFalse(bool val) {
+	if (val) return u"TRUE"_s;
+	return u"FALSE"_s;
 }
 
-//static
-QStringList RKSettingsModuleR::makeRRunTimeOptionCommands () {
-	RK_TRACE (SETTINGS);
+// static
+QStringList RKSettingsModuleR::makeRRunTimeOptionCommands() {
+	RK_TRACE(SETTINGS);
 	QStringList list;
 
 	QString outdec = options_outdec;
-	if (outdec.isEmpty()) outdec = '.';
-	list.append ("options (OutDec=\"" + outdec + "\")\n");
-	list.append ("options (width=" + QString::number (options_width) + ")\n");
-	list.append ("options (warn=" + QString::number (options_warn) + ")\n");
-	list.append ("options (max.print=" + QString::number (options_maxprint) + ")\n");
-	list.append ("options (warnings.length=" + QString::number (options_warningslength) + ")\n");
-	list.append ("options (keep.source=" + RTrueFalse(options_keepsource) + ")\n");
-	list.append ("options (keep.source.pkgs=" + RTrueFalse(options_keepsourcepkgs) + ")\n");
-	list.append ("options (expressions=" + QString::number (options_expressions) + ")\n");
-	list.append ("options (digits=" + QString::number (options_digits) + ")\n");
-	list.append ("options (checkbounds=" + RTrueFalse(options_checkbounds) + ")\n");
-	if (options_editor == builtin_editor) list.append ("options (editor=rk.edit.files)\n");
-	else list.append ("options (editor=\"" + options_editor.get() + "\")\n");
-	if (options_pager == builtin_editor) list.append ("options (pager=rk.show.files)\n");
-	else list.append ("options (pager=\"" + options_pager.get() + "\")\n");
-	if (!options_further.get().isEmpty ()) list.append (options_further.get() + '\n');
-	if (!options_addpaths.get().isEmpty ()) {
-		QString command = "rk.adjust.system.path (add=c(";
+	if (outdec.isEmpty()) outdec = u'.';
+	list.append(u"options (OutDec=\""_s + outdec + u"\")\n"_s);
+	list.append(u"options (width="_s + QString::number(options_width) + u")\n"_s);
+	list.append(u"options (warn="_s + QString::number(options_warn) + u")\n"_s);
+	list.append(u"options (max.print="_s + QString::number(options_maxprint) + u")\n"_s);
+	list.append(u"options (warnings.length="_s + QString::number(options_warningslength) + u")\n"_s);
+	list.append(u"options (keep.source="_s + RTrueFalse(options_keepsource) + u")\n"_s);
+	list.append(u"options (keep.source.pkgs="_s + RTrueFalse(options_keepsourcepkgs) + u")\n"_s);
+	list.append(u"options (expressions="_s + QString::number(options_expressions) + u")\n"_s);
+	list.append(u"options (digits="_s + QString::number(options_digits) + u")\n"_s);
+	list.append(u"options (checkbounds="_s + RTrueFalse(options_checkbounds) + u")\n"_s);
+	if (options_editor == builtin_editor) list.append(u"options (editor=rk.edit.files)\n"_s);
+	else list.append(u"options (editor=\""_s + options_editor.get() + u"\")\n"_s);
+	if (options_pager == builtin_editor) list.append(u"options (pager=rk.show.files)\n"_s);
+	else list.append(u"options (pager=\""_s + options_pager.get() + u"\")\n"_s);
+	if (!options_further.get().isEmpty()) list.append(options_further.get() + u'\n');
+	if (!options_addpaths.get().isEmpty()) {
+		QString command = u"rk.adjust.system.path (add=c("_s;
 		for (const QString &p : std::as_const(options_addpaths.get())) {
-			command.append (RObject::rQuote (p));
+			command.append(RObject::rQuote(p));
 		}
-		list.append (command + "))\n");
+		list.append(command + u"))\n"_s);
 	}
 
-	list.append ("options (help_type=\"html\")\n");		// for R 2.10.0 and above
-	list.append ("options (browser=rk.show.html)\n");
-	list.append ("options (askYesNo=rk.askYesNo)\n"); // for R 3.5.0 and above
+	list.append(u"options (help_type=\"html\")\n"_s); // for R 2.10.0 and above
+	list.append(u"options (browser=rk.show.html)\n"_s);
+	list.append(u"options (askYesNo=rk.askYesNo)\n"_s); // for R 3.5.0 and above
 
 	return list;
 }
@@ -269,7 +270,7 @@ QStringList RKSettingsModuleR::makeRRunTimeOptionCommands () {
 void RKSettingsModuleR::syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a) {
 	RK_TRACE(SETTINGS);
 
-	KConfigGroup cg = config->group("R Settings");
+	KConfigGroup cg = config->group(QStringLiteral("R Settings"));
 	options_outdec.syncConfig(cg, a);
 	options_width.syncConfig(cg, a);
 	options_warn.syncConfig(cg, a);
@@ -292,8 +293,8 @@ void RKSettingsModuleR::syncConfig(KConfig *config, RKConfigBase::ConfigSyncActi
 //#################################################
 
 // static members
-RKConfigValue<QStringList> RKSettingsModuleRPackages::liblocs {"LibraryLocations", QStringList()};
-RKConfigValue<bool> RKSettingsModuleRPackages::archive_packages {"archive packages", false};
+RKConfigValue<QStringList> RKSettingsModuleRPackages::liblocs{"LibraryLocations", QStringList()};
+RKConfigValue<bool> RKSettingsModuleRPackages::archive_packages{"archive packages", false};
 #if (defined Q_OS_WIN || defined Q_OS_MACOS)
 #	if (defined USE_BINARY_PACKAGES)
 #		define USE_SOURCE_PACKAGES false
@@ -303,16 +304,16 @@ RKConfigValue<bool> RKSettingsModuleRPackages::archive_packages {"archive packag
 #else
 #	define USE_SOURCE_PACKAGES true
 #endif
-RKConfigValue<bool> RKSettingsModuleRPackages::source_packages {"source_packages", USE_SOURCE_PACKAGES};
+RKConfigValue<bool> RKSettingsModuleRPackages::source_packages{"source_packages", USE_SOURCE_PACKAGES};
 #define RKWARD_REPO "https://files.kde.org/rkward/R/"
-RKConfigValue<QStringList> RKSettingsModuleRPackages::package_repositories {"Repositories", QStringList(RKWARD_REPO)};
-QString RKSettingsModuleRPackages::essential_packages = QString ("base\nmethods\nutils\ngrDevices\ngraphics\nrkward");
-RKConfigValue<QString> RKSettingsModuleRPackages::cran_mirror_url {"CRAN mirror url", "@CRAN@"};
+RKConfigValue<QStringList> RKSettingsModuleRPackages::package_repositories{"Repositories", QStringList(QStringLiteral(RKWARD_REPO))};
+QString RKSettingsModuleRPackages::essential_packages = u"base\nmethods\nutils\ngrDevices\ngraphics\nrkward"_s;
+RKConfigValue<QString> RKSettingsModuleRPackages::cran_mirror_url{"CRAN mirror url", u"@CRAN@"_s};
 QStringList RKSettingsModuleRPackages::defaultliblocs;
 QString RKSettingsModuleRPackages::r_libs_user;
 
 class RKSettingsPageRPackages : public RKSettingsModuleWidget {
-public:
+  public:
 	RKSettingsPageRPackages(QWidget *parent, RKSettingsModule *parent_module) : RKSettingsModuleWidget(parent, parent_module, RKSettingsModuleRPackages::page_id, RKSettingsModulePlugins::addons_superpage_id) {
 		RK_TRACE(SETTINGS);
 
@@ -321,18 +322,18 @@ public:
 
 		QVBoxLayout *main_vbox = new QVBoxLayout(this);
 
-		main_vbox->addSpacing(2*RKStyle::spacingHint());
+		main_vbox->addSpacing(2 * RKStyle::spacingHint());
 
 		main_vbox->addWidget(new QLabel(i18n("CRAN download mirror (leave empty to be prompted once each session):"), this));
-		QHBoxLayout* hbox = new QHBoxLayout();
+		QHBoxLayout *hbox = new QHBoxLayout();
 		main_vbox->addLayout(hbox);
 		auto cran_mirror_input = RKSettingsModuleRPackages::cran_mirror_url.makeLineEdit(this);
-		if (RKSettingsModuleRPackages::cran_mirror_url == "@CRAN@") cran_mirror_input->clear();
+		if (RKSettingsModuleRPackages::cran_mirror_url == QStringLiteral("@CRAN@")) cran_mirror_input->clear();
 		hbox->addWidget(cran_mirror_input);
-		QPushButton* cran_mirror_button = new QPushButton(i18n("Select mirror"), this);
+		QPushButton *cran_mirror_button = new QPushButton(i18n("Select mirror"), this);
 		connect(cran_mirror_button, &QPushButton::clicked, this, [this, cran_mirror_input]() {
 			QString title = i18n("Select CRAN mirror");
-			RCommand* command = new RCommand("rk.select.CRAN.mirror()\n", RCommand::App | RCommand::GetStringVector, title);
+			RCommand *command = new RCommand(QStringLiteral("rk.select.CRAN.mirror()\n"), RCommand::App | RCommand::GetStringVector, title);
 			connect(command->notifier(), &RCommandNotifier::commandFinished, cran_mirror_input, [cran_mirror_input](RCommand *command) {
 				if (command->succeeded()) {
 					RK_ASSERT(command->getDataLength() >= 1);
@@ -340,7 +341,7 @@ public:
 				}
 			});
 
-			RKProgressControl* control = new RKProgressControl(this, title, title, RKProgressControl::CancellableProgress);
+			RKProgressControl *control = new RKProgressControl(this, title, title, RKProgressControl::CancellableProgress);
 			control->addRCommand(command, true);
 			RInterface::issueCommand(command, parentModule()->commandChain());
 			control->doModal(true);
@@ -365,7 +366,7 @@ public:
 		source_packages_box->setChecked(true);
 		source_packages_box->setEnabled(false);
 #endif
-		RKCommonFunctions::setTips(QString("<p>%1</p>").arg(i18n("Installing packages from pre-compiled binaries (if available) is generally faster, and does not require an installation of development tools and libraries. On the other hand, building packages from source provides best compatibility.")), source_packages_box);
+		RKCommonFunctions::setTips(QStringLiteral("<p>%1</p>").arg(i18n("Installing packages from pre-compiled binaries (if available) is generally faster, and does not require an installation of development tools and libraries. On the other hand, building packages from source provides best compatibility.")), source_packages_box);
 		main_vbox->addWidget(source_packages_box);
 
 		hbox = new QHBoxLayout();
@@ -374,7 +375,7 @@ public:
 		auto label = RKCommonFunctions::wordWrappedLabel(i18n("Some add-on packages are not available in the CRAN repository, but can be installed from development repositories. Use the button \"%1\", to install such packages, comfortably.", button->text()));
 		hbox->addWidget(label);
 		hbox->setStretchFactor(label, 2);
-		connect(button, &QPushButton::clicked, this, []() { RKComponentMap::getMap()->invokeComponent("rkward::install_from_git", QStringList()); });
+		connect(button, &QPushButton::clicked, this, []() { RKComponentMap::getMap()->invokeComponent(QStringLiteral("rkward::install_from_git"), QStringList()); });
 		hbox->addWidget(button);
 
 		main_vbox->addStretch();
@@ -387,11 +388,11 @@ public:
 			dialog.setWindowTitle(i18n("Add R Library Directory"));
 			QVBoxLayout *layout = new QVBoxLayout(&dialog);
 			layout->addWidget(RKCommonFunctions::wordWrappedLabel(
-				i18n("Specify or select library location to add.\nNote that locations may contain a '%v', which will expand to the first "
-				     "two components of the R version number (e.g. to 3.5), automatically. Including this is recommended, because R packages "
-				     "compiled for one version of R will often fail to work correctly in a different version of R.")));
+			    i18n("Specify or select library location to add.\nNote that locations may contain a '%v', which will expand to the first "
+			         "two components of the R version number (e.g. to 3.5), automatically. Including this is recommended, because R packages "
+			         "compiled for one version of R will often fail to work correctly in a different version of R.")));
 			KUrlRequester *req = new KUrlRequester();
-			req->setText(QDir(RKSettingsModuleGeneral::filesPath()).absoluteFilePath("library/%v"));
+			req->setText(QDir(RKSettingsModuleGeneral::filesPath()).absoluteFilePath(QStringLiteral("library/%v")));
 			req->setMode(KFile::Directory);
 			layout->addWidget(req);
 
@@ -414,10 +415,10 @@ public:
 	void applyChanges() override {
 		RK_TRACE(SETTINGS);
 
-		if (RKSettingsModuleRPackages::cran_mirror_url.get().isEmpty ()) RKSettingsModuleRPackages::cran_mirror_url = "@CRAN@";
+		if (RKSettingsModuleRPackages::cran_mirror_url.get().isEmpty()) RKSettingsModuleRPackages::cran_mirror_url = QStringLiteral("@CRAN@");
 
 		RKSettingsModuleRPackages::package_repositories = repository_selector->getValues();
-		RKSettingsModuleRPackages::liblocs = libloc_selector->getValues ();
+		RKSettingsModuleRPackages::liblocs = libloc_selector->getValues();
 
 		// apply options in R
 		QStringList commands = RKSettingsModuleRPackages::makeRRunTimeOptionCommands();
@@ -425,7 +426,8 @@ public:
 			RInterface::issueCommand(new RCommand(*it, RCommand::App), parentModule()->commandChain());
 		}
 	}
-private:
+
+  private:
 	MultiStringSelector *libloc_selector;
 	MultiStringSelector *repository_selector;
 };
@@ -434,108 +436,113 @@ RKSettingsModuleRPackages::RKSettingsModuleRPackages(QObject *parent) : RKSettin
 	RK_TRACE(SETTINGS);
 }
 
-RKSettingsModuleRPackages::~RKSettingsModuleRPackages () {
-	RK_TRACE (SETTINGS);
+RKSettingsModuleRPackages::~RKSettingsModuleRPackages() {
+	RK_TRACE(SETTINGS);
 }
 
 void RKSettingsModuleRPackages::createPages(RKSettings *parent) {
 	parent->addSettingsPage(new RKSettingsPageRPackages(parent, this));
 }
 
-void RKSettingsModuleRPackages::addLibraryLocation (const QString& new_loc, RCommandChain *chain) {
-	RK_TRACE (SETTINGS);
+void RKSettingsModuleRPackages::addLibraryLocation(const QString &new_loc, RCommandChain *chain) {
+	RK_TRACE(SETTINGS);
 
-	if (!libraryLocations ().contains (new_loc)) liblocs.get().prepend (new_loc);
+	if (!libraryLocations().contains(new_loc)) liblocs.get().prepend(new_loc);
 
 	// update the backend in any case. User might have changed liblocs, there.
-	RInterface::issueCommand(new RCommand(".libPaths (unique (c (" + RObject::rQuote (new_loc) + ", .libPaths ())))", RCommand::App | RCommand::Sync), chain);
+	RInterface::issueCommand(new RCommand(u".libPaths (unique (c ("_s + RObject::rQuote(new_loc) + u", .libPaths ())))"_s, RCommand::App | RCommand::Sync),
+	                         chain);
 }
 
-QStringList expandLibLocs (const QStringList &in) {
+QStringList expandLibLocs(const QStringList &in) {
 	QStringList ret;
-	for (int i = 0; i < in.size (); ++i) {
+	for (int i = 0; i < in.size(); ++i) {
 		QString dummy = in[i];
-		ret.append (dummy.replace (QLatin1String ("%v"), RKSessionVars::RVersion (true)));
+		ret.append(dummy.replace("%v"_L1, RKSessionVars::RVersion(true)));
 	}
 	return ret;
 }
 
-QString RKSettingsModuleRPackages::userLibraryLocation () {
+QString RKSettingsModuleRPackages::userLibraryLocation() {
 	if (!r_libs_user.isEmpty()) return r_libs_user;
-	return QDir (RKSettingsModuleGeneral::filesPath ()).absoluteFilePath ("library/" + RKSessionVars::RVersion (true));
+	return QDir(RKSettingsModuleGeneral::filesPath()).absoluteFilePath(u"library/"_s + RKSessionVars::RVersion(true));
 }
 
-QStringList RKSettingsModuleRPackages::libraryLocations () {
-	return (QStringList (userLibraryLocation ()) + expandLibLocs (liblocs.get() + defaultliblocs));
+QStringList RKSettingsModuleRPackages::libraryLocations() {
+	return (QStringList(userLibraryLocation()) + expandLibLocs(liblocs.get() + defaultliblocs));
 }
 
-QStringList RKSettingsModuleRPackages::addUserLibLocTo (const QStringList& liblocs) {
-	if (!liblocs.contains(userLibraryLocation ())) return (QStringList (userLibraryLocation ()) + liblocs);
+QStringList RKSettingsModuleRPackages::addUserLibLocTo(const QStringList &liblocs) {
+	if (!liblocs.contains(userLibraryLocation())) return (QStringList(userLibraryLocation()) + liblocs);
 	return liblocs;
 }
 
-QString RKSettingsModuleRPackages::libLocsCommand () {
-	RK_TRACE (SETTINGS);
+QString RKSettingsModuleRPackages::libLocsCommand() {
+	RK_TRACE(SETTINGS);
 
 	// For additional library locations configured inside RKWard, try to create them, as needed.
 	// This is especially important for versioned dirs (which will not exist after upgrading R, for instance)
 	QString command;
 	if (!liblocs.get().isEmpty()) {
 		bool first = true;
-		command = "local({\naddpaths <- unique (c(";
+		command = u"local({\naddpaths <- unique (c("_s;
 		const QStringList ll = expandLibLocs(liblocs);
-		for (const QString& libloc : ll) {
-			if (first) first = false;
-			else command.append (", ");
-			command.append (RObject::rQuote (libloc));
+		for (const QString &libloc : ll) {
+			if (first)
+				first = false;
+			else
+				command.append(u", "_s);
+			command.append(RObject::rQuote(libloc));
 		}
-		command.append ("))\nlapply(addpaths, function(p) { if (!dir.exists(p)) try(dir.create(p, recursive=TRUE)) })\n})\n");
+		command.append(u"))\nlapply(addpaths, function(p) { if (!dir.exists(p)) try(dir.create(p, recursive=TRUE)) })\n})\n"_s);
 	}
 
 	// For add library locations set "the R way", try to interfere as little as possible.
-	command.append(".libPaths (unique (c (");
+	command.append(u".libPaths (unique (c ("_s);
 	bool first = true;
-	const QStringList ll = libraryLocations ();
-	for (const QString& libloc : ll) {
-		if (first) first = false;
-		else command.append (", ");
-		command.append (RObject::rQuote (libloc));
+	const QStringList ll = libraryLocations();
+	for (const QString &libloc : ll) {
+		if (first)
+			first = false;
+		else
+			command.append(u", "_s);
+		command.append(RObject::rQuote(libloc));
 	}
-	command.append (")))");
+	command.append(u")))"_s);
 
 	return command;
 }
 
-//static
-QString RKSettingsModuleRPackages::pkgTypeOption () {
+// static
+QString RKSettingsModuleRPackages::pkgTypeOption() {
 	QString ret;
 #if defined Q_OS_WIN || defined Q_OS_MACOS
-	ret.append("options (pkgType=\"");
-	if (source_packages) ret.append("source");
-	else ret.append("binary");   // "automatically select appropriate binary"
-	ret.append("\")\n");
+	ret.append(u"options (pkgType=\""_s);
+	if (source_packages) ret.append(u"source"_s);
+	else ret.append(u"both"_s); // "automatically select appropriate binary, if available, else consider source package"
+	ret.append(u"\")\n"_s);
 #endif
 	return ret;
 }
 
-//static
-QStringList RKSettingsModuleRPackages::makeRRunTimeOptionCommands () {
-	RK_TRACE (SETTINGS);
+// static
+QStringList RKSettingsModuleRPackages::makeRRunTimeOptionCommands() {
+	RK_TRACE(SETTINGS);
 	QStringList list;
 
-// package repositories
-	QString command = "options (repos=c (CRAN=" + RObject::rQuote (cran_mirror_url);
-	for (auto it = package_repositories.get().constBegin (); it != package_repositories.get().constEnd(); ++it) {
-		command.append (", " + RObject::rQuote (*it));
+	// package repositories
+	QString command = u"options (repos=c (CRAN="_s + RObject::rQuote(cran_mirror_url);
+	for (auto it = package_repositories.get().constBegin(); it != package_repositories.get().constEnd(); ++it) {
+		command.append(u", "_s + RObject::rQuote(*it));
 	}
-	list.append (command + "))\n");
+	list.append(command + u"))\n"_s);
 
 #if defined Q_OS_WIN || defined Q_OS_MACOS
-	list.append (pkgTypeOption ());
+	list.append(pkgTypeOption());
 #endif
 
-// library locations
-	list.append (libLocsCommand ());
+	// library locations
+	list.append(libLocsCommand());
 
 	return list;
 }
@@ -543,48 +550,52 @@ QStringList RKSettingsModuleRPackages::makeRRunTimeOptionCommands () {
 void RKSettingsModuleRPackages::syncConfig(KConfig *config, RKConfigBase::ConfigSyncAction a) {
 	RK_TRACE(SETTINGS);
 
-	KConfigGroup cg = config->group("R Settings");
+	KConfigGroup cg = config->group(u"R Settings"_s);
 	cran_mirror_url.syncConfig(cg, a);
 	liblocs.syncConfig(cg, a);
 	archive_packages.syncConfig(cg, a);
-	source_packages.syncConfig(cg, a);  // NOTE: does not take effect on Linux, see pkgTypeOption
+	source_packages.syncConfig(cg, a); // NOTE: does not take effect on Linux, see pkgTypeOption
 	package_repositories.syncConfig(cg, a);
 
 	if (a == RKConfigBase::LoadConfig) {
-		if (RKSettingsModuleGeneral::storedConfigVersion () < RKSettingsModuleGeneral::RKWardConfig_0_6_3) {
+		if (RKSettingsModuleGeneral::storedConfigVersion() < RKSettingsModuleGeneral::RKWardConfig_0_6_3) {
 			auto v = package_repositories.get();
-			v.removeAll("http://rkward.sf.net/R");
-			v.append(RKWARD_REPO);
+			v.removeAll(u"http://rkward.sf.net/R"_s);
+			v.append(QStringLiteral(RKWARD_REPO));
 			package_repositories = v;
 		}
 	}
 }
 
-void RKSettingsModuleRPackages::validateSettingsInteractive (QList<RKSetupWizardItem*>* items) {
-	RK_TRACE (SETTINGS);
+void RKSettingsModuleRPackages::validateSettingsInteractive(QList<RKSetupWizardItem *> *items) {
+	RK_TRACE(SETTINGS);
 
-	if (RKSettingsModuleGeneral::storedConfigVersion () < RKSettingsModuleGeneral::RKWardConfig_0_7_1) {
-		QString legacy_libloc = QDir (RKSettingsModuleGeneral::filesPath ()).absoluteFilePath ("library");
+	if (RKSettingsModuleGeneral::storedConfigVersion() < RKSettingsModuleGeneral::RKWardConfig_0_7_1) {
+		QString legacy_libloc = QDir(RKSettingsModuleGeneral::filesPath()).absoluteFilePath(u"library"_s);
 		if (liblocs.get().contains(legacy_libloc)) {
 			auto item = new RKSetupWizardItem(i18n("Unversioned library location"), i18n("The configured library locations (where R packages will be installed on this system) contains the directory '%1', "
-			                                  "which was suggested as a default library location in earlier versions of RKWard. Use of this directory is no longer "
-			                                  "recommended, as it is not accessible to R sessions outside of RKWard (unless configured, explicitly). Also due to the lack "
-			                                  "of an R version number in the directory name, it offers no protection against using packages built for an incompatible "
-			                                  "version of R.", legacy_libloc), RKSetupWizardItem::Warning);
+			                                                                             "which was suggested as a default library location in earlier versions of RKWard. Use of this directory is no longer "
+			                                                                             "recommended, as it is not accessible to R sessions outside of RKWard (unless configured, explicitly). Also due to the lack "
+			                                                                             "of an R version number in the directory name, it offers no protection against using packages built for an incompatible "
+			                                                                             "version of R.",
+			                                                                             legacy_libloc),
+			                                  RKSetupWizardItem::Warning);
 			item->addOption(i18nc("verb", "Rename"), i18n("Rename this location to include the version number of the currently running R. Packages will continue "
-			                                        "to work (if they are compatible with this version of R)."), [legacy_libloc](RKSetupWizard*) {
-									liblocs.get().removeAll(legacy_libloc);
-									QString new_loc = legacy_libloc + '-' + RKSessionVars::RVersion (true);
-									RInterface::issueCommand (QString ("file.rename(%1, %2)\n").arg(RObject::rQuote(legacy_libloc), RObject::rQuote (new_loc)), RCommand::App);
-									liblocs.get().prepend (legacy_libloc + QStringLiteral ("-%v"));
-									RInterface::issueCommand (libLocsCommand(), RCommand::App);
-								});
+			                                              "to work (if they are compatible with this version of R)."),
+			                [legacy_libloc](RKSetupWizard *) {
+				                liblocs.get().removeAll(legacy_libloc);
+				                QString new_loc = legacy_libloc + u'-' + RKSessionVars::RVersion(true);
+				                RInterface::issueCommand(u"file.rename(%1, %2)\n"_s.arg(RObject::rQuote(legacy_libloc), RObject::rQuote(new_loc)), RCommand::App);
+				                liblocs.get().prepend(legacy_libloc + u"-%v"_s);
+				                RInterface::issueCommand(libLocsCommand(), RCommand::App);
+			                });
 			item->addOption(i18nc("verb", "Remove"), i18n("Remove this location from the configuration (it will not be deleted on disk). You will have to "
-			                                        "re-install any packages that you want to keep."), [legacy_libloc](RKSetupWizard*) {
-									liblocs.get().removeAll(legacy_libloc);
-									RInterface::issueCommand (libLocsCommand(), RCommand::App);
-								});
-			item->addOption(i18nc("verb", "Keep"), i18n("Keep this location (do not change anything)"), [](RKSetupWizard*) {});
+			                                              "re-install any packages that you want to keep."),
+			                [legacy_libloc](RKSetupWizard *) {
+				                liblocs.get().removeAll(legacy_libloc);
+				                RInterface::issueCommand(libLocsCommand(), RCommand::App);
+			                });
+			item->addOption(i18nc("verb", "Keep"), i18n("Keep this location (do not change anything)"), [](RKSetupWizard *) {});
 
 			items->append(item);
 		}
