@@ -1,6 +1,6 @@
 /*
 rksettingsmodulewatch - This file is part of the RKWard project. Created: Thu Aug 26 2004
-SPDX-FileCopyrightText: 2004-2024 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileCopyrightText: 2004-2025 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
 SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,10 +19,9 @@ Settings module for the RInterface-watch. Allows you to configure what kind of c
 
 @author Thomas Friedrichsmeier
 */
-class RKSettingsModuleWatch : public RKSettingsModule
-{
-Q_OBJECT
-public:
+class RKSettingsModuleWatch : public RKSettingsModule {
+	Q_OBJECT
+  public:
 	explicit RKSettingsModuleWatch(QObject *parent);
 	~RKSettingsModuleWatch() override;
 
@@ -30,25 +29,34 @@ public:
 	void createPages(RKSettings *parent) override;
 	static constexpr PageId page_id = QLatin1String("commandlog");
 
-	static bool shouldShowInput (RCommand *command);
-	static bool shouldShowOutput (RCommand *command);
-	static bool shouldShowError (RCommand *command);
-	static bool shouldRaiseWindow (RCommand *command);
+	static bool shouldShowInput(RCommand *command);
+	static bool shouldShowOutput(RCommand *command);
+	static bool shouldShowError(RCommand *command);
+	static bool shouldRaiseWindow(RCommand *command);
 
-	static uint maxLogLines () { return max_log_lines; };
+	static uint maxLogLines() { return max_log_lines; };
 
 	static RKSettingsModuleWatch *instance() { return _instance; };
-private:
-friend class RKSettingsPageWatch;
-	enum FilterType { ShowInput=1, ShowOutput=2, ShowError=4, RaiseWindow=8 };
+	static void forTestingSuppressOutput(bool suppress) {
+		if (suppress) all_suppressed++;
+		else all_suppressed--;
+	};
+
+  private:
+	friend class RKSettingsPageWatch;
+	enum FilterType { ShowInput = 1,
+		              ShowOutput = 2,
+		              ShowError = 4,
+		              RaiseWindow = 8 };
 
 	static RKConfigValue<int> plugin_filter;
 	static RKConfigValue<int> app_filter;
 	static RKConfigValue<int> sync_filter;
 	static RKConfigValue<int> user_filter;
+	static int all_suppressed;
 
 	static RKConfigValue<uint> max_log_lines;
-	static RKSettingsModuleWatch* _instance;
+	static RKSettingsModuleWatch *_instance;
 };
 
 #endif
