@@ -6,7 +6,8 @@ result <- leveneTest (warpbreaks[["breaks"]], warpbreaks[["tension"]])
 ## Print result
 names <- rk.get.description (warpbreaks[["breaks"]], warpbreaks[["tension"]])
 
-rk.header ("Levene's Test", list ("response variable", names[1], "groups", names[2]))
+rk.header ("Levene's Test", parameters=list("response variable"=names[1],
+	"groups"=names[2]))
 
 rk.print (result)
 })
